@@ -1,36 +1,33 @@
 from __future__ import annotations
 from typing import Optional, List
 
-from spotipy2.types import SimplifiedArtist
+from spotipy2 import types
 
 
-class Track:
+class Track(types.BaseType):
     def __init__(
         self,
-        album,
-        artists,
+        artists: List[dict],
         disc_number: int,
         duration_ms: int,
         explicit: bool,
-        external_ids,
         external_urls,
         href: str,
         id: str,
         is_local: bool,
         name: str,
-        popularity: int,
         preview_url: str,
         track_number: int,
         type: str,
         uri: str,
+        album: dict = None,
+        external_ids: dict = None,
+        popularity: int = None,
         available_markets: Optional[List[str]] = None,
-        is_playable: bool = None,
-        linked_from: bool = None,
-        restrictions: dict = None,
         **kwargs
     ):
-        self.album = album
-        self.artists = [SimplifiedArtist.from_dict(a) for a in artists]
+        self.album = types.SimplifiedAlbum.from_dict(album) if album else None
+        self.artists = [types.SimplifiedArtist.from_dict(a) for a in artists]
         self.available_markets = available_markets
         self.disc_number = disc_number
         self.duration_ms = duration_ms
@@ -46,9 +43,6 @@ class Track:
         self.track_number = track_number
         self.type = type
         self.uri = uri
-        self.is_playable = is_playable
-        self.linked_from = linked_from
-        self.restrictions = restrictions
 
     @classmethod
     def from_dict(cls, d: dict) -> Track:
